# Welcome to the SAP Help Portal
Find SAP product documentation.

All products
English
More
### [SAP Business Suite](https://help.sap.com/docs/portfolio-category/business-suite)
####  [Business AI (Joule)](https://help.sap.com/docs/JOULE)
####  [SAP Business Data Cloud](https://help.sap.com/docs/portfolio-category/data-cloud)
  * [SAP Business Data Cloud](https://help.sap.com/docs/SAP_BUSINESS_DATA_CLOUD)
  * [SAP Datasphere](https://help.sap.com/docs/SAP_DATASPHERE)
  * [SAP Analytics Cloud](https://help.sap.com/docs/SAP_ANALYTICS_CLOUD)
  * [SAP HANA Cloud](https://help.sap.com/docs/HANA_CLOUD)
  * [SAP Master Data Governance](https://help.sap.com/docs/MASTER_DATA_GOVERNANCE)
  * [SAP Business Warehouse](https://help.sap.com/docs/SAP_BUSINESS_WAREHOUSE)


####  [Enterprise resource planning](https://help.sap.com/docs/portfolio-category/erp)
  * [SAP S/⁠4HANA Cloud Public Edition](https://help.sap.com/docs/SAP_S4HANA_CLOUD)
  * [SAP S/⁠4HANA Cloud Private Edition](https://help.sap.com/docs/SAP_S4HANA_CLOUD_PE)
  * [SAP S/⁠4HANA](https://help.sap.com/docs/SAP_S4HANA_ON-PREMISE)
  * [SAP ERP](https://help.sap.com/docs/SAP_ERP)
  * [SAP Business One](https://help.sap.com/docs/SAP_BUSINESS_ONE_PRODUCT_LINE)
  * [SAP Business ByDesign](https://help.sap.com/docs/SAP_BUSINESS_BYDESIGN)


####  [Business Technology Platform](https://help.sap.com/docs/BTP)
  * [Application Development and Automation](https://help.sap.com/docs/btp#use_task-application-development-and-automation)
  * [Data](https://help.sap.com/docs/portfolio-category/DATABASE_AND_DATA_MANAGEMENT)
  * [Analytics](https://help.sap.com/docs/SAP_ANALYTICS)
  * [Integration](https://help.sap.com/docs/btp#use_task-integration)
  * [Artificial Intelligence](https://help.sap.com/docs/btp#use_task-artificial-intelligence)


### [By category](https://help.sap.com/docs/portfolio-category/BY_CATEGORY)
####  [Financial management](https://help.sap.com/docs/portfolio-category/FINANCIAL_MANAGEMENT)
  * [Financial planning and analysis](https://help.sap.com/docs/portfolio-category/FINANCIAL_PLANNING_AND_ANALYSIS)
  * [Accounting and financial close](https://help.sap.com/docs/portfolio-category/ACCOUNTING_AND_FINANCIAL_CLOSE)
  * [Tax management](https://help.sap.com/docs/portfolio-category/TAX_MANAGEMENT)
  * [Treasury management](https://help.sap.com/docs/portfolio-category/TREASURY_MANAGEMENT)
  * [Accounts receivable, billing and revenue management](https://help.sap.com/docs/portfolio-category/ACCOUNTS_RECEIVABLE_BILLING_AND_REVENUE_MANAGEMENT)
  * [Governance, risk, compliance (GRC) and cybersecurity](https://help.sap.com/docs/portfolio-category/GRC_AND_CYBERSECURITY)
  * [Quote-to-Cash](https://help.sap.com/docs/portfolio-category/QUOTE-TO-CASH)


####  [Spend management](https://help.sap.com/docs/portfolio-category/NETWORK_AND_SPEND_MANAGEMENT)
  * [Supplier management](https://help.sap.com/docs/portfolio-category/SUPPLIER_MANAGEMENT)
  * [Sourcing and Contracts](https://help.sap.com/docs/ARIBA_SOURCING)
  * [Procurement](https://help.sap.com/docs/ARIBA_PROCUREMENT)
  * [Invoices and Payments](https://help.sap.com/docs/ARIBA_PROCUREMENT?task=use_task#use_task-invoices-and-payments)
  * [Category Management](https://help.sap.com/docs/CATMAN)
  * [Services Procurement and External Workforce](https://help.sap.com/docs/SAP_Fieldglass)
  * [Travel and Expense](https://help.sap.com/docs/SAP_CONCUR)


####  [Supply chain management](https://help.sap.com/docs/portfolio-category/SUPPLY_CHAIN_MANAGEMENT)
  * [Supply chain planning](https://help.sap.com/docs/portfolio-category/SUPPLY_CHAIN_PLANNING)
  * [Supply chain logistics](https://help.sap.com/docs/portfolio-category/SUPPLY_CHAIN_LOGISTICS)
  * [Manufacturing](https://help.sap.com/docs/portfolio-category/MANUFACTURING)
  * [Product lifecycle management](https://help.sap.com/docs/portfolio-category/PRODUCT_LIFECYCLE_MANAGEMENT)
  * [Enterprise asset management](https://help.sap.com/docs/portfolio-category/ENTERPRISE_ASSET_MANAGEMENT)


####  [Human capital management](https://help.sap.com/docs/portfolio-category/HR_AND_PEOPLE_ENGAGEMENT)
  * [SAP SuccessFactors Platform](https://help.sap.com/docs/SAP_SUCCESSFACTORS_PLATFORM)
  * [Core HR and Payroll](https://help.sap.com/docs/portfolio-category/CORE_HR_AND_PAYROLL)
  * [Talent Management](https://help.sap.com/docs/portfolio-category/TALENT_MANAGEMENT)
  * [Employee Experience Management](https://help.sap.com/docs/portfolio-category/EMPLOYEE_MANAGEMENT)
  * [Workforce Analytics](https://help.sap.com/docs/portfolio-category/WORKFORCE_ANALYTICS)


####  [Customer experience](https://help.sap.com/docs/SAP_CX)
  * [E-Commerce](https://help.sap.com/docs/COMMERCE)
  * [Customer Data](https://help.sap.com/docs/CUSTOMER_DATA_MANAGEMENT)
  * [Sales Automation](https://help.sap.com/docs/SALES)
  * [Customer Service](https://help.sap.com/docs/SERVICE)
  * [Marketing](https://help.sap.com/docs/MARKETING)
  * [Artificial Intelligence](https://help.sap.com/docs/CX_ARTIFICIAL_INTELLIGENCE)
  * [Sales Performance Management](https://help.sap.com/docs/SAP_Sales_Performance_Management)


####  [Sustainability management](https://help.sap.com/docs/portfolio-category/sustainability)
  * [SAP Sustainability Control Tower](https://help.sap.com/docs/SAP_SUS_SCT)
  * [SAP Sustainability Footprint Management](https://help.sap.com/docs/sustainability-footprint-management)
  * [SAP Responsible Design and Production](https://help.sap.com/docs/sap-responsible-design-and-production)
  * [SAP Sustainability Data Exchange](https://help.sap.com/docs/sdx)
  * [SAP Green Ledger](https://help.sap.com/docs/green-ledger)
  * [SAP Green Token](https://help.sap.com/docs/greentoken)


### [Business Transformation Management](https://help.sap.com/docs/portfolio-category/BTM)
####  [SAP Signavio](https://help.sap.com/docs/signavio-process-transformation-suite)
####  [SAP LeanIX](https://help.sap.com/docs/LEANIX)
####  [SAP ERP Transformation with Integrated Toolchain](https://help.sap.com/docs/ERP_ITC/32b885380e024123a72d0bf4908c8fc9/063cd5ee40834e6eb6eae6eb96d5b8b6.html)

### Get Support
  * [Glossary](https://help.sap.com/glossary)
The SAP Glossary contains definitions for SAP terminology and components.
  * [SAP Store (Information published on SAP site)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fstore.sap.com%2F)
Discover, try, and buy SAP and partner solutions online.
  * [SAP Community (Information published on SAP site)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fcommunity.sap.com%2F)
Post questions and share your knowledge with other users and experts.
  * [SAP Support (Information published on SAP site)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.sap.com%2Fen%2Findex.html)
Find solutions and get answers from SAP.
  * [SAP Developer Center (Information published on SAP site)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdevelopers.sap.com%2F)
A different view on the SAP Community, customized for developers.
  * [SAP Training & Certification (Information published on SAP site)](https://help.sap.com/docs/link-disclaimer?site=http%3A%2F%2Fwww.sap.com%2Ftraining-certification.html)
Research all training and certification programs at SAP.


![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
